--	This will be the module table
local M				= {}
local title			= "Dynamic GUI"
local okText		= "Ok"
local showOptions	= false

--	This is the callback that is called once a GUI event is triggered
local function GUICallback( mode, str )
	
	--	Extract args
	local args	= unserialize( str )
	
	--	Clicked a button
	if mode == "button" then
	
		--	Button: Options
		if args.button == "btOptions" then
		
			--	Toggle options
			showOptions = not showOptions
		
		--	Button: Ok
		elseif args.button == "btOk" then
		
			--	Update title
			if args.txtTitle and args.txtTitle ~= "" then
				title = args.txtTitle
			end
			
			--	Update button Ok text
			if args.txtOk and args.txtOk ~= "" then
				okText	= args.txtOk
			end
			
			--	Hide options
			showOptions = false
			
		end
		
		--	Reload GUI
		M.showGUI()
		
	end
end

--	Adds the option controls to the GUI
local function addOptionsGUI()
	if not showOptions then return "" end
	return [[
control
	type = text
	name = txtTitle
	description = Title
	
control
	type = text
	name = txtOk
	description = Button Ok text
]]
end

--	This is the function that displays the GUI
local function showGUI()
	local g		= [[beamngguiconfig 1
callback system dynamicGUI.GUICallback
title ]] .. title .. [[ 

container
	type = verticalStack
	name = root
	
control
	type = button
	name = btOptions
	icon = tools/gui/images/]] .. ( showOptions and [[iconDelete.png]] or [[iconAdd.png]] ) .. [[ 
	description = Options
	
]] .. addOptionsGUI() .. [[ 
	
control
	type = button
	name = btOk
	icon = tools/gui/images/iconAccept.png
	description = ]] .. okText .. [[ 
	
control
	type = doneButton
	icon = tools/gui/images/iconCancel.png
	description = Close
	
]]
	gameEngine:showGUI( g )
end

--	Public interface
--	Defines what is visible to the outside world
M.showGUI		= showGUI
M.GUICallback	= GUICallback

--	Return the module table
return M